California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 011 - REQUIRES PRIVATE-SECTOR EMERGENCY AMBULANCE EMPLOYEES TO REMAIN ON-CALL DURING WORK BREAKS. ELIMINATES CERTAIN EMPLOYER LIABILITY. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400272 | YES ON 11 - CALIFORNIANS FOR EMERGENCY PREPAREDNESS AND SAFETY, COMMITTEE MAJOR FUNDING FROM AMERICAN MEDICAL RESPONSE (AMR) | SUPPORT